# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/topology/v1/topologies.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import level_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/topology/v1/topologies.proto',
  package='systemathics.apis.services.topology.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7systemathics/apis/services/topology/v1/topologies.proto\x12&systemathics.apis.services.topology.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a,systemathics/apis/type/shared/v1/level.proto\"\xb7\x02\n\x11TopologiesRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x36\n\x05level\x18\x02 \x01(\x0e\x32\'.systemathics.apis.type.shared.v1.Level\x12P\n\x0bgranularity\x18\x03 \x01(\x0e\x32;.systemathics.apis.services.topology.v1.TopologyGranularity\x12*\n\x05start\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"f\n\rTopologyEntry\x12 \n\x05\x62\x65gin\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\x1e\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x11.google.type.Date\x12\x13\n\x0bticks_count\x18\x03 \x01(\x04\"n\n\x12TopologiesResponse\x12\x46\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x35.systemathics.apis.services.topology.v1.TopologyEntry\x12\x10\n\x08has_more\x18\x02 \x01(\x08*\xe2\x01\n\x13TopologyGranularity\x12$\n TOPOLOGY_GRANULARITY_UNSPECIFIED\x10\x00\x12\x1e\n\x1aTOPOLOGY_GRANULARITY_DAILY\x10\x01\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_WEEKLY\x10\x02\x12 \n\x1cTOPOLOGY_GRANULARITY_MONTHLY\x10\x03\x12!\n\x1dTOPOLOGY_GRANULARITY_QUATERLY\x10\x04\x12\x1f\n\x1bTOPOLOGY_GRANULARITY_YEARLY\x10\x05\x32\x99\x01\n\x11TopologiesService\x12\x83\x01\n\nTopologies\x12\x39.systemathics.apis.services.topology.v1.TopologiesRequest\x1a:.systemathics.apis.services.topology.v1.TopologiesResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2.DESCRIPTOR,])

_TOPOLOGYGRANULARITY = _descriptor.EnumDescriptor(
  name='TopologyGranularity',
  full_name='systemathics.apis.services.topology.v1.TopologyGranularity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_DAILY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_WEEKLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_MONTHLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_QUATERLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TOPOLOGY_GRANULARITY_YEARLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=783,
  serialized_end=1009,
)
_sym_db.RegisterEnumDescriptor(_TOPOLOGYGRANULARITY)

TopologyGranularity = enum_type_wrapper.EnumTypeWrapper(_TOPOLOGYGRANULARITY)
TOPOLOGY_GRANULARITY_UNSPECIFIED = 0
TOPOLOGY_GRANULARITY_DAILY = 1
TOPOLOGY_GRANULARITY_WEEKLY = 2
TOPOLOGY_GRANULARITY_MONTHLY = 3
TOPOLOGY_GRANULARITY_QUATERLY = 4
TOPOLOGY_GRANULARITY_YEARLY = 5



_TOPOLOGIESREQUEST = _descriptor.Descriptor(
  name='TopologiesRequest',
  full_name='systemathics.apis.services.topology.v1.TopologiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granularity', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.granularity', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='systemathics.apis.services.topology.v1.TopologiesRequest.count', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=564,
)


_TOPOLOGYENTRY = _descriptor.Descriptor(
  name='TopologyEntry',
  full_name='systemathics.apis.services.topology.v1.TopologyEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='begin', full_name='systemathics.apis.services.topology.v1.TopologyEntry.begin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='systemathics.apis.services.topology.v1.TopologyEntry.end', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticks_count', full_name='systemathics.apis.services.topology.v1.TopologyEntry.ticks_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=668,
)


_TOPOLOGIESRESPONSE = _descriptor.Descriptor(
  name='TopologiesResponse',
  full_name='systemathics.apis.services.topology.v1.TopologiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='systemathics.apis.services.topology.v1.TopologiesResponse.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_more', full_name='systemathics.apis.services.topology.v1.TopologiesResponse.has_more', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=670,
  serialized_end=780,
)

_TOPOLOGIESREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_TOPOLOGIESREQUEST.fields_by_name['level'].enum_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_level__pb2._LEVEL
_TOPOLOGIESREQUEST.fields_by_name['granularity'].enum_type = _TOPOLOGYGRANULARITY
_TOPOLOGIESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_TOPOLOGIESREQUEST.fields_by_name['count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_TOPOLOGYENTRY.fields_by_name['begin'].message_type = google_dot_type_dot_date__pb2._DATE
_TOPOLOGYENTRY.fields_by_name['end'].message_type = google_dot_type_dot_date__pb2._DATE
_TOPOLOGIESRESPONSE.fields_by_name['entries'].message_type = _TOPOLOGYENTRY
DESCRIPTOR.message_types_by_name['TopologiesRequest'] = _TOPOLOGIESREQUEST
DESCRIPTOR.message_types_by_name['TopologyEntry'] = _TOPOLOGYENTRY
DESCRIPTOR.message_types_by_name['TopologiesResponse'] = _TOPOLOGIESRESPONSE
DESCRIPTOR.enum_types_by_name['TopologyGranularity'] = _TOPOLOGYGRANULARITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopologiesRequest = _reflection.GeneratedProtocolMessageType('TopologiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESREQUEST,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesRequest)
  })
_sym_db.RegisterMessage(TopologiesRequest)

TopologyEntry = _reflection.GeneratedProtocolMessageType('TopologyEntry', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYENTRY,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologyEntry)
  })
_sym_db.RegisterMessage(TopologyEntry)

TopologiesResponse = _reflection.GeneratedProtocolMessageType('TopologiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGIESRESPONSE,
  '__module__' : 'systemathics.apis.services.topology.v1.topologies_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.topology.v1.TopologiesResponse)
  })
_sym_db.RegisterMessage(TopologiesResponse)



_TOPOLOGIESSERVICE = _descriptor.ServiceDescriptor(
  name='TopologiesService',
  full_name='systemathics.apis.services.topology.v1.TopologiesService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1012,
  serialized_end=1165,
  methods=[
  _descriptor.MethodDescriptor(
    name='Topologies',
    full_name='systemathics.apis.services.topology.v1.TopologiesService.Topologies',
    index=0,
    containing_service=None,
    input_type=_TOPOLOGIESREQUEST,
    output_type=_TOPOLOGIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TOPOLOGIESSERVICE)

DESCRIPTOR.services_by_name['TopologiesService'] = _TOPOLOGIESSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/time_interval.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/time_interval.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4systemathics/apis/type/shared/v1/time_interval.proto\x12 systemathics.apis.type.shared.v1\x1a\x1bgoogle/type/timeofday.proto\"d\n\x0cTimeInterval\x12*\n\nstart_time\x18\x01 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12(\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x16.google.type.TimeOfDayb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_timeofday__pb2.DESCRIPTOR,])




_TIMEINTERVAL = _descriptor.Descriptor(
  name='TimeInterval',
  full_name='systemathics.apis.type.shared.v1.TimeInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='systemathics.apis.type.shared.v1.TimeInterval.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='systemathics.apis.type.shared.v1.TimeInterval.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=219,
)

_TIMEINTERVAL.fields_by_name['start_time'].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
_TIMEINTERVAL.fields_by_name['end_time'].message_type = google_dot_type_dot_timeofday__pb2._TIMEOFDAY
DESCRIPTOR.message_types_by_name['TimeInterval'] = _TIMEINTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeInterval = _reflection.GeneratedProtocolMessageType('TimeInterval', (_message.Message,), {
  'DESCRIPTOR' : _TIMEINTERVAL,
  '__module__' : 'systemathics.apis.type.shared.v1.time_interval_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.type.shared.v1.TimeInterval)
  })
_sym_db.RegisterMessage(TimeInterval)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/static_data/v1/static_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/static_data/v1/static_data.proto',
  package='systemathics.apis.services.static_data.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;systemathics/apis/services/static_data/v1/static_data.proto\x12)systemathics.apis.services.static_data.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"\xbb\x04\n\x11StaticDataRequest\x12H\n\nasset_type\x18\x01 \x01(\x0e\x32\x34.systemathics.apis.services.static_data.v1.AssetType\x12*\n\x04name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08\x65xchange\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12,\n\x06ticker\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_contract\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0f\x66uture_category\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\requity_sector\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05index\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04\x63ode\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x05start\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12*\n\x05\x63ount\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xb2\x02\n\x12StaticDataResponse\x12G\n\x07\x66utures\x18\x01 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.FutureEntry\x12H\n\x08\x65quities\x18\x02 \x03(\x0b\x32\x36.systemathics.apis.services.static_data.v1.EquityEntry\x12\x41\n\x04\x65tfs\x18\x03 \x03(\x0b\x32\x33.systemathics.apis.services.static_data.v1.EtfEntry\x12\x46\n\x07indices\x18\x04 \x03(\x0b\x32\x35.systemathics.apis.services.static_data.v1.IndexEntry\"\x8b\x05\n\x0b\x45quityEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12T\n\x07mapping\x18\x08 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x0c\n\x04isin\x18\x0f \x01(\t\x12\r\n\x05\x63usip\x18\x10 \x01(\t\x12\r\n\x05sedol\x18\x11 \x01(\t\x12T\n\x07sectors\x18\x12 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x05\n\x08\x45tfEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12Q\n\x07mapping\x18\x08 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x0c\n\x04isin\x18\x0f \x01(\t\x12\r\n\x05\x63usip\x18\x10 \x01(\t\x12\r\n\x05sedol\x18\x11 \x01(\t\x12Q\n\x07sectors\x18\x12 \x03(\x0b\x32@.systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry\x12\x34\n\x0e\x63\x61pitalization\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cSectorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa3\x05\n\x0b\x46utureEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12T\n\x07mapping\x18\x08 \x03(\x0b\x32\x43.systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x12\n\nunderlying\x18\x0f \x01(\t\x12\x10\n\x08\x63ontract\x18\x10 \x01(\t\x12V\n\x08\x63\x61tegory\x18\x11 \x03(\x0b\x32\x44.systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry\x12\r\n\x05\x63hain\x18\x12 \x01(\t\x12#\n\x08maturity\x18\x13 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05month\x18\x14 \x01(\t\x12\x0c\n\x04year\x18\x15 \x01(\x05\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rCategoryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x03\n\nIndexEntry\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08\x63urrency\x18\x05 \x01(\t\x12\x0f\n\x07primary\x18\x06 \x01(\t\x12\x16\n\x0etick_size_rule\x18\x07 \x01(\t\x12S\n\x07mapping\x18\x08 \x03(\x0b\x32\x42.systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry\x12\r\n\x05index\x18\t \x01(\t\x12\x0c\n\x04open\x18\n \x01(\t\x12\r\n\x05\x63lose\x18\x0b \x01(\t\x12\x11\n\ttime_zone\x18\x0c \x01(\t\x12\x10\n\x08lot_size\x18\r \x01(\x03\x12\x13\n\x0bpoint_value\x18\x0e \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x0f \x01(\t\x1a.\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\x93\x01\n\tAssetType\x12\x1a\n\x16\x41SSET_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41SSET_TYPE_ALL\x10\x01\x12\x15\n\x11\x41SSET_TYPE_EQUITY\x10\x02\x12\x15\n\x11\x41SSET_TYPE_FUTURE\x10\x03\x12\x12\n\x0e\x41SSET_TYPE_ETF\x10\x04\x12\x14\n\x10\x41SSET_TYPE_INDEX\x10\x05\x32\x9f\x01\n\x11StaticDataService\x12\x89\x01\n\nStaticData\x12<.systemathics.apis.services.static_data.v1.StaticDataRequest\x1a=.systemathics.apis.services.static_data.v1.StaticDataResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,])

_ASSETTYPE = _descriptor.EnumDescriptor(
  name='AssetType',
  full_name='systemathics.apis.services.static_data.v1.AssetType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_ALL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_EQUITY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_FUTURE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_ETF', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSET_TYPE_INDEX', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3515,
  serialized_end=3662,
)
_sym_db.RegisterEnumDescriptor(_ASSETTYPE)

AssetType = enum_type_wrapper.EnumTypeWrapper(_ASSETTYPE)
ASSET_TYPE_UNSPECIFIED = 0
ASSET_TYPE_ALL = 1
ASSET_TYPE_EQUITY = 2
ASSET_TYPE_FUTURE = 3
ASSET_TYPE_ETF = 4
ASSET_TYPE_INDEX = 5



_STATICDATAREQUEST = _descriptor.Descriptor(
  name='StaticDataRequest',
  full_name='systemathics.apis.services.static_data.v1.StaticDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_type', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.asset_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exchange', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.exchange', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.ticker', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future_contract', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.future_contract', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='future_category', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.future_category', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='equity_sector', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.equity_sector', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.index', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.code', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.start', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='systemathics.apis.services.static_data.v1.StaticDataRequest.count', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=785,
)


_STATICDATARESPONSE = _descriptor.Descriptor(
  name='StaticDataResponse',
  full_name='systemathics.apis.services.static_data.v1.StaticDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='futures', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.futures', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='equities', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.equities', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etfs', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.etfs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='indices', full_name='systemathics.apis.services.static_data.v1.StaticDataResponse.indices', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=788,
  serialized_end=1094,
)


_EQUITYENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_EQUITYENTRY_SECTORSENTRY = _descriptor.Descriptor(
  name='SectorsEntry',
  full_name='systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1748,
)

_EQUITYENTRY = _descriptor.Descriptor(
  name='EquityEntry',
  full_name='systemathics.apis.services.static_data.v1.EquityEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.EquityEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.EquityEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.EquityEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.EquityEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.EquityEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.EquityEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.EquityEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.EquityEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.EquityEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.EquityEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.EquityEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.EquityEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.EquityEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.EquityEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isin', full_name='systemathics.apis.services.static_data.v1.EquityEntry.isin', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cusip', full_name='systemathics.apis.services.static_data.v1.EquityEntry.cusip', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sedol', full_name='systemathics.apis.services.static_data.v1.EquityEntry.sedol', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sectors', full_name='systemathics.apis.services.static_data.v1.EquityEntry.sectors', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capitalization', full_name='systemathics.apis.services.static_data.v1.EquityEntry.capitalization', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EQUITYENTRY_MAPPINGENTRY, _EQUITYENTRY_SECTORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1097,
  serialized_end=1748,
)


_ETFENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_ETFENTRY_SECTORSENTRY = _descriptor.Descriptor(
  name='SectorsEntry',
  full_name='systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1748,
)

_ETFENTRY = _descriptor.Descriptor(
  name='EtfEntry',
  full_name='systemathics.apis.services.static_data.v1.EtfEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.EtfEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.EtfEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.EtfEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.EtfEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.EtfEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.EtfEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.EtfEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.EtfEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.EtfEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.EtfEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.EtfEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.EtfEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.EtfEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.EtfEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isin', full_name='systemathics.apis.services.static_data.v1.EtfEntry.isin', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cusip', full_name='systemathics.apis.services.static_data.v1.EtfEntry.cusip', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sedol', full_name='systemathics.apis.services.static_data.v1.EtfEntry.sedol', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sectors', full_name='systemathics.apis.services.static_data.v1.EtfEntry.sectors', index=17,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capitalization', full_name='systemathics.apis.services.static_data.v1.EtfEntry.capitalization', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ETFENTRY_MAPPINGENTRY, _ETFENTRY_SECTORSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1751,
  serialized_end=2393,
)


_FUTUREENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_FUTUREENTRY_CATEGORYENTRY = _descriptor.Descriptor(
  name='CategoryEntry',
  full_name='systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3024,
  serialized_end=3071,
)

_FUTUREENTRY = _descriptor.Descriptor(
  name='FutureEntry',
  full_name='systemathics.apis.services.static_data.v1.FutureEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.FutureEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.FutureEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.FutureEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.FutureEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.FutureEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.FutureEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.FutureEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.FutureEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.FutureEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.FutureEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.FutureEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.FutureEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.FutureEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.FutureEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='underlying', full_name='systemathics.apis.services.static_data.v1.FutureEntry.underlying', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract', full_name='systemathics.apis.services.static_data.v1.FutureEntry.contract', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='systemathics.apis.services.static_data.v1.FutureEntry.category', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain', full_name='systemathics.apis.services.static_data.v1.FutureEntry.chain', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maturity', full_name='systemathics.apis.services.static_data.v1.FutureEntry.maturity', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='month', full_name='systemathics.apis.services.static_data.v1.FutureEntry.month', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='year', full_name='systemathics.apis.services.static_data.v1.FutureEntry.year', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FUTUREENTRY_MAPPINGENTRY, _FUTUREENTRY_CATEGORYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2396,
  serialized_end=3071,
)


_INDEXENTRY_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1654,
  serialized_end=1700,
)

_INDEXENTRY = _descriptor.Descriptor(
  name='IndexEntry',
  full_name='systemathics.apis.services.static_data.v1.IndexEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.static_data.v1.IndexEntry.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='systemathics.apis.services.static_data.v1.IndexEntry.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='systemathics.apis.services.static_data.v1.IndexEntry.country', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='systemathics.apis.services.static_data.v1.IndexEntry.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='systemathics.apis.services.static_data.v1.IndexEntry.currency', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary', full_name='systemathics.apis.services.static_data.v1.IndexEntry.primary', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_size_rule', full_name='systemathics.apis.services.static_data.v1.IndexEntry.tick_size_rule', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mapping', full_name='systemathics.apis.services.static_data.v1.IndexEntry.mapping', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='index', full_name='systemathics.apis.services.static_data.v1.IndexEntry.index', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='systemathics.apis.services.static_data.v1.IndexEntry.open', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='systemathics.apis.services.static_data.v1.IndexEntry.close', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_zone', full_name='systemathics.apis.services.static_data.v1.IndexEntry.time_zone', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lot_size', full_name='systemathics.apis.services.static_data.v1.IndexEntry.lot_size', index=12,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_value', full_name='systemathics.apis.services.static_data.v1.IndexEntry.point_value', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='systemathics.apis.services.static_data.v1.IndexEntry.description', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_INDEXENTRY_MAPPINGENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3074,
  serialized_end=3512,
)

_STATICDATAREQUEST.fields_by_name['asset_type'].enum_type = _ASSETTYPE
_STATICDATAREQUEST.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['exchange'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['ticker'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['future_contract'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['future_category'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['equity_sector'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['index'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_STATICDATAREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_STATICDATAREQUEST.fields_by_name['count'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_STATICDATARESPONSE.fields_by_name['futures'].message_type = _FUTUREENTRY
_STATICDATARESPONSE.fields_by_name['equities'].message_type = _EQUITYENTRY
_STATICDATARESPONSE.fields_by_name['etfs'].message_type = _ETFENTRY
_STATICDATARESPONSE.fields_by_name['indices'].message_type = _INDEXENTRY
_EQUITYENTRY_MAPPINGENTRY.containing_type = _EQUITYENTRY
_EQUITYENTRY_SECTORSENTRY.containing_type = _EQUITYENTRY
_EQUITYENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_EQUITYENTRY.fields_by_name['mapping'].message_type = _EQUITYENTRY_MAPPINGENTRY
_EQUITYENTRY.fields_by_name['sectors'].message_type = _EQUITYENTRY_SECTORSENTRY
_EQUITYENTRY.fields_by_name['capitalization'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_ETFENTRY_MAPPINGENTRY.containing_type = _ETFENTRY
_ETFENTRY_SECTORSENTRY.containing_type = _ETFENTRY
_ETFENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_ETFENTRY.fields_by_name['mapping'].message_type = _ETFENTRY_MAPPINGENTRY
_ETFENTRY.fields_by_name['sectors'].message_type = _ETFENTRY_SECTORSENTRY
_ETFENTRY.fields_by_name['capitalization'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FUTUREENTRY_MAPPINGENTRY.containing_type = _FUTUREENTRY
_FUTUREENTRY_CATEGORYENTRY.containing_type = _FUTUREENTRY
_FUTUREENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_FUTUREENTRY.fields_by_name['mapping'].message_type = _FUTUREENTRY_MAPPINGENTRY
_FUTUREENTRY.fields_by_name['category'].message_type = _FUTUREENTRY_CATEGORYENTRY
_FUTUREENTRY.fields_by_name['maturity'].message_type = google_dot_type_dot_date__pb2._DATE
_INDEXENTRY_MAPPINGENTRY.containing_type = _INDEXENTRY
_INDEXENTRY.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_INDEXENTRY.fields_by_name['mapping'].message_type = _INDEXENTRY_MAPPINGENTRY
DESCRIPTOR.message_types_by_name['StaticDataRequest'] = _STATICDATAREQUEST
DESCRIPTOR.message_types_by_name['StaticDataResponse'] = _STATICDATARESPONSE
DESCRIPTOR.message_types_by_name['EquityEntry'] = _EQUITYENTRY
DESCRIPTOR.message_types_by_name['EtfEntry'] = _ETFENTRY
DESCRIPTOR.message_types_by_name['FutureEntry'] = _FUTUREENTRY
DESCRIPTOR.message_types_by_name['IndexEntry'] = _INDEXENTRY
DESCRIPTOR.enum_types_by_name['AssetType'] = _ASSETTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StaticDataRequest = _reflection.GeneratedProtocolMessageType('StaticDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _STATICDATAREQUEST,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticDataRequest)
  })
_sym_db.RegisterMessage(StaticDataRequest)

StaticDataResponse = _reflection.GeneratedProtocolMessageType('StaticDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATICDATARESPONSE,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.StaticDataResponse)
  })
_sym_db.RegisterMessage(StaticDataResponse)

EquityEntry = _reflection.GeneratedProtocolMessageType('EquityEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _EQUITYENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry.MappingEntry)
    })
  ,

  'SectorsEntry' : _reflection.GeneratedProtocolMessageType('SectorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _EQUITYENTRY_SECTORSENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry.SectorsEntry)
    })
  ,
  'DESCRIPTOR' : _EQUITYENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EquityEntry)
  })
_sym_db.RegisterMessage(EquityEntry)
_sym_db.RegisterMessage(EquityEntry.MappingEntry)
_sym_db.RegisterMessage(EquityEntry.SectorsEntry)

EtfEntry = _reflection.GeneratedProtocolMessageType('EtfEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _ETFENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry.MappingEntry)
    })
  ,

  'SectorsEntry' : _reflection.GeneratedProtocolMessageType('SectorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _ETFENTRY_SECTORSENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry.SectorsEntry)
    })
  ,
  'DESCRIPTOR' : _ETFENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.EtfEntry)
  })
_sym_db.RegisterMessage(EtfEntry)
_sym_db.RegisterMessage(EtfEntry.MappingEntry)
_sym_db.RegisterMessage(EtfEntry.SectorsEntry)

FutureEntry = _reflection.GeneratedProtocolMessageType('FutureEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _FUTUREENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry.MappingEntry)
    })
  ,

  'CategoryEntry' : _reflection.GeneratedProtocolMessageType('CategoryEntry', (_message.Message,), {
    'DESCRIPTOR' : _FUTUREENTRY_CATEGORYENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry.CategoryEntry)
    })
  ,
  'DESCRIPTOR' : _FUTUREENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.FutureEntry)
  })
_sym_db.RegisterMessage(FutureEntry)
_sym_db.RegisterMessage(FutureEntry.MappingEntry)
_sym_db.RegisterMessage(FutureEntry.CategoryEntry)

IndexEntry = _reflection.GeneratedProtocolMessageType('IndexEntry', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _INDEXENTRY_MAPPINGENTRY,
    '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
    # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.IndexEntry.MappingEntry)
    })
  ,
  'DESCRIPTOR' : _INDEXENTRY,
  '__module__' : 'systemathics.apis.services.static_data.v1.static_data_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.static_data.v1.IndexEntry)
  })
_sym_db.RegisterMessage(IndexEntry)
_sym_db.RegisterMessage(IndexEntry.MappingEntry)


_EQUITYENTRY_MAPPINGENTRY._options = None
_EQUITYENTRY_SECTORSENTRY._options = None
_ETFENTRY_MAPPINGENTRY._options = None
_ETFENTRY_SECTORSENTRY._options = None
_FUTUREENTRY_MAPPINGENTRY._options = None
_FUTUREENTRY_CATEGORYENTRY._options = None
_INDEXENTRY_MAPPINGENTRY._options = None

_STATICDATASERVICE = _descriptor.ServiceDescriptor(
  name='StaticDataService',
  full_name='systemathics.apis.services.static_data.v1.StaticDataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3665,
  serialized_end=3824,
  methods=[
  _descriptor.MethodDescriptor(
    name='StaticData',
    full_name='systemathics.apis.services.static_data.v1.StaticDataService.StaticData',
    index=0,
    containing_service=None,
    input_type=_STATICDATAREQUEST,
    output_type=_STATICDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STATICDATASERVICE)

DESCRIPTOR.services_by_name['StaticDataService'] = _STATICDATASERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/type/shared/v1/action.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/type/shared/v1/action.proto',
  package='systemathics.apis.type.shared.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-systemathics/apis/type/shared/v1/action.proto\x12 systemathics.apis.type.shared.v1*B\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x0e\n\nACTION_SET\x10\x01\x12\x10\n\x0c\x41\x43TION_CLEAR\x10\x02\x62\x06proto3'
)

_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='systemathics.apis.type.shared.v1.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_SET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_CLEAR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=83,
  serialized_end=149,
)
_sym_db.RegisterEnumDescriptor(_ACTION)

Action = enum_type_wrapper.EnumTypeWrapper(_ACTION)
ACTION_UNSPECIFIED = 0
ACTION_SET = 1
ACTION_CLEAR = 2


DESCRIPTOR.enum_types_by_name['Action'] = _ACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/daily_analytics/v1/daily_rsi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='systemathics/apis/services/daily_analytics/v1/daily_rsi.proto',
  package='systemathics.apis.services.daily_analytics.v1',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=systemathics/apis/services/daily_analytics/v1/daily_rsi.proto\x12-systemathics.apis.services.daily_analytics.v1\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xbb\x01\n\x0f\x44\x61ilyRsiRequest\x12@\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.Identifier\x12\x42\n\x0b\x63onstraints\x18\x02 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.Constraints\x12\x0e\n\x06length\x18\x03 \x01(\x05\x12\x12\n\nadjustment\x18\x04 \x01(\x08\"]\n\x10\x44\x61ilyRsiResponse\x12I\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32;.systemathics.apis.services.daily_analytics.v1.DailyRsiData\"K\n\x0c\x44\x61ilyRsiData\x12\x1f\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.Date\x12\r\n\x05value\x18\x02 \x01(\x01\x12\x0b\n\x03rsi\x18\x03 \x01(\x01\x32\x9f\x01\n\x0f\x44\x61ilyRsiService\x12\x8b\x01\n\x08\x44\x61ilyRsi\x12>.systemathics.apis.services.daily_analytics.v1.DailyRsiRequest\x1a?.systemathics.apis.services.daily_analytics.v1.DailyRsiResponseb\x06proto3'
  ,
  dependencies=[google_dot_type_dot_date__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2.DESCRIPTOR,systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2.DESCRIPTOR,])




_DAILYRSIREQUEST = _descriptor.Descriptor(
  name='DailyRsiRequest',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiRequest.identifier', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiRequest.constraints', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiRequest.length', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adjustment', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiRequest.adjustment', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=427,
)


_DAILYRSIRESPONSE = _descriptor.Descriptor(
  name='DailyRsiResponse',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiResponse.data', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=429,
  serialized_end=522,
)


_DAILYRSIDATA = _descriptor.Descriptor(
  name='DailyRsiData',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiData.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiData.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rsi', full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiData.rsi', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=524,
  serialized_end=599,
)

_DAILYRSIREQUEST.fields_by_name['identifier'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2._IDENTIFIER
_DAILYRSIREQUEST.fields_by_name['constraints'].message_type = systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2._CONSTRAINTS
_DAILYRSIRESPONSE.fields_by_name['data'].message_type = _DAILYRSIDATA
_DAILYRSIDATA.fields_by_name['date'].message_type = google_dot_type_dot_date__pb2._DATE
DESCRIPTOR.message_types_by_name['DailyRsiRequest'] = _DAILYRSIREQUEST
DESCRIPTOR.message_types_by_name['DailyRsiResponse'] = _DAILYRSIRESPONSE
DESCRIPTOR.message_types_by_name['DailyRsiData'] = _DAILYRSIDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DailyRsiRequest = _reflection.GeneratedProtocolMessageType('DailyRsiRequest', (_message.Message,), {
  'DESCRIPTOR' : _DAILYRSIREQUEST,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyRsiRequest)
  })
_sym_db.RegisterMessage(DailyRsiRequest)

DailyRsiResponse = _reflection.GeneratedProtocolMessageType('DailyRsiResponse', (_message.Message,), {
  'DESCRIPTOR' : _DAILYRSIRESPONSE,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyRsiResponse)
  })
_sym_db.RegisterMessage(DailyRsiResponse)

DailyRsiData = _reflection.GeneratedProtocolMessageType('DailyRsiData', (_message.Message,), {
  'DESCRIPTOR' : _DAILYRSIDATA,
  '__module__' : 'systemathics.apis.services.daily_analytics.v1.daily_rsi_pb2'
  # @@protoc_insertion_point(class_scope:systemathics.apis.services.daily_analytics.v1.DailyRsiData)
  })
_sym_db.RegisterMessage(DailyRsiData)



_DAILYRSISERVICE = _descriptor.ServiceDescriptor(
  name='DailyRsiService',
  full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=602,
  serialized_end=761,
  methods=[
  _descriptor.MethodDescriptor(
    name='DailyRsi',
    full_name='systemathics.apis.services.daily_analytics.v1.DailyRsiService.DailyRsi',
    index=0,
    containing_service=None,
    input_type=_DAILYRSIREQUEST,
    output_type=_DAILYRSIRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DAILYRSISERVICE)

DESCRIPTOR.services_by_name['DailyRsiService'] = _DAILYRSISERVICE

# @@protoc_insertion_point(module_scope)
